@@ -1,22 +1,11 @@
-import asyncio
-
-from dataclasses import dataclass
-from typing import Any, Awaitable, Dict, List, Tuple, Optional, Callable, Sequence
+from typing import Any, Awaitable, Callable, Dict, Sequence, Tuple
 
 from dazl import AIOPartyClient, Command
 
-from .log import LOG
-
 from ..api import IntegrationQueueEvents, IntegrationQueueSink
-
-from .common import \
-    InvocationStatus, \
-    without_return_value, \
-    as_handler_invocation
-
-from .integration_deferral_queue import \
-    IntegrationDeferralQueue
-
+from .common import InvocationStatus, as_handler_invocation, without_return_value
+from .integration_deferral_queue import IntegrationDeferralQueue
+from .log import LOG
 
 IntegrationQueueHandler = Callable[[Any], Awaitable[Sequence[Command]]]
 
